@@ -86,7 +86,7 @@
 #define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGGUI_NO_DEPRECATED
-#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
+#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
 #  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55600
+#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
@@ -198,7 +198,7 @@
 #define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGGUI_NO_DEPRECATED
-#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
+#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
 #  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -208,7 +208,7 @@
 #  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55600
+#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
